Get fit indices from objects generated by tidyLPA.
get_fit(x, ...)
# S3 method for class 'tidyLPA'
get_fit(x, ...)
# S3 method for class 'tidyProfile'
get_fit(x, ...)A tibble. Learn more at https://data-edu.github.io/tidyLPA/articles/Introduction_to_tidyLPA.html#getting-fit-statistics
get_fit(tidyLPA): Get fit indices for a latent profile analysis with
multiple numbers of classes and models, of class 'tidyLPA'.
get_fit(tidyProfile): Get fit indices for a single latent profile analysis
object, of class 'tidyProfile'.
if (FALSE) { # \dontrun{
if(interactive()){
results <- iris %>%
select(Sepal.Length, Sepal.Width, Petal.Length, Petal.Width) %>%
estimate_profiles(3)
get_fit(results)
get_fit(results[[1]])
}
} # }