S3 method 'print' for class 'tidyProfile'.
# S3 method for class 'tidyProfile'
print(x, digits = 2, na.print = "", ...)An object of class 'tidyProfile'.
minimal number of significant digits, see
print.default.
a character string which is used to indicate NA values in
printed output, or NULL. See print.default.
further arguments to be passed to or from other methods. They are ignored in this function.
if (FALSE) { # \dontrun{
if(interactive()){
tmp <- iris %>%
select(Sepal.Length, Sepal.Width, Petal.Length, Petal.Width) %>%
estimate_profiles(3)
tmp[[2]]
}
} # }